@@ -25,9 +25,10 @@ module BootstrapForm
     autoload :PhoneField
     autoload :RadioButton
     autoload :RangeField
-    autoload :RichTextArea if Rails::VERSION::MAJOR >= 6
+    autoload :RichTextArea
     autoload :SearchField
     autoload :Select
+    autoload :Submit
     autoload :TelephoneField
     autoload :TextArea
     autoload :TextField
